{% extends "site_base_wider.html" %}

{% block "metas" %}
    <title>{{ _('Add Page') }} &#8212; {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ _('Add a new page') }}" />
{% endblock "metas" %}

{% block "metainfo" %}
    <h1>{{ _('Add Page') }} &#8212; {{ settings.SITE_TITLE }}</h1>
    <p>{{ _('Add a new page') }}</p>
{% endblock "metainfo" %}

{% block "breadcrumbs" %}
<ul class="breadcrumb">
  <li><a href="{% url app_blog-index %}">{{ _('Home') }}</a> <span class="divider">/</span></li>
  {# <li class="active"><a href="{% url app_wiki-detail page.slug %}">{{ page.title }}</a></li> #}
</ul>
{% endblock "breadcrumbs" %}

{% block "content" %}
<section id="posts">
    <article class="post">
        <form action="" method="POST" class="form-horizontal">
            {% csrf_token %}
            {{ form.as_p }}
            <input type="submit" class="btn btn-info" value="{{ _('Submit') }}" />
        </form>
    </article>
</section>
{% endblock "content" %}

{% block "tagcloud" %}
{% endblock "tagcloud" %}
