# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='django-rwiki',
    version='0.0.2',
    author=u'Oscar M. Lage Guitian',
    author_email='r0sk10@gmail.com',
    #packages=['rwiki'],
    packages = find_packages(),
    include_package_data = True,
    package_data = {'': ['rwiki/templates', 'rwiki/static','rwiki/fixtures',]},
    url='http://bitbucket.org/r0sk/django-rwiki',
    license='BSD licence, see LICENSE file',
    description='Yet another Django Wiki App',
    zip_safe=False,
    long_description=open('README.rst').read(),
    install_requires=[
        "Django < 1.5",
        "South == 0.7.5",
        "PIL == 1.1.7",
        "django-filebrowser-no-grappelli == 3.1.1",
        "sorl-thumbnail == 11.12",
        "django-compressor == 1.1.2",
        "django-reversion == 1.6.3",
        "diff-match-patch==20120106",
    ],
    keywords = "django application wiki",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
